complete -c rattler-build -n "__fish_use_subcommand" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_use_subcommand" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_use_subcommand" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_use_subcommand" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_use_subcommand" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c rattler-build -n "__fish_use_subcommand" -f -a "build" -d 'Build a package'
complete -c rattler-build -n "__fish_use_subcommand" -f -a "test" -d 'Test a package'
complete -c rattler-build -n "__fish_use_subcommand" -f -a "rebuild" -d 'Rebuild a package'
complete -c rattler-build -n "__fish_use_subcommand" -f -a "upload" -d 'Upload a package'
complete -c rattler-build -n "__fish_use_subcommand" -f -a "completion" -d 'Generate shell completion script'
complete -c rattler-build -n "__fish_use_subcommand" -f -a "generate-recipe" -d 'Generate a recipe from PyPI or CRAN'
complete -c rattler-build -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -s r -l recipe -d 'The recipe file or directory containing `recipe.yaml`. Defaults to the current directory' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l target-platform -d 'The target platform for the build' -r
complete -c rattler-build -n "__fish_seen_subcommand_from build" -s c -l channel -d 'Add the channels needed for the recipe using this option. For more then one channel use it multiple times. The default channel is `conda-forge`' -r
complete -c rattler-build -n "__fish_seen_subcommand_from build" -s m -l variant-config -d 'Variant configuration files for the build' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l package-format -d 'The package format to use for the build. Can be one of `tar-bz2` or `conda`. You can also add a compression level to the package format, e.g. `tar-bz2:<number>` (from 1 to 9) or `conda:<number>` (from -7 to 22)' -r
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l compression-threads -d 'The number of threads to use for compression (only relevant when also using `--package-format conda`)' -r
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l output-dir -d 'Output directory for build artifacts. Defaults to `./output`' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l auth-file -d 'Path to an auth-file to read authentication information from' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l render-only -d 'Render the recipe files without executing the build'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l keep-build -d 'Keep intermediate build artifacts after the build'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l no-build-id -d 'Don\'t use build id(timestamp) when creating build directory name. Defaults to `false`'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l no-include-recipe -d 'Do not store the recipe in the final package'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l no-test -d 'Do not run tests after building'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l color-build-log -d 'Do not force colors in the output of the build script'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l use-zstd -d 'Enable support for repodata.json.zst'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l use-bz2 -d 'Enable support for repodata.json.bz2'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -l experimental -d 'Enable experimental features'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from build" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from test" -s c -l channel -d 'Channels to use when testing' -r
complete -c rattler-build -n "__fish_seen_subcommand_from test" -s p -l package-file -d 'The package file to test' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from test" -l output-dir -d 'Output directory for build artifacts. Defaults to `./output`' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from test" -l auth-file -d 'Path to an auth-file to read authentication information from' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from test" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from test" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from test" -l use-zstd -d 'Enable support for repodata.json.zst'
complete -c rattler-build -n "__fish_seen_subcommand_from test" -l use-bz2 -d 'Enable support for repodata.json.bz2'
complete -c rattler-build -n "__fish_seen_subcommand_from test" -l experimental -d 'Enable experimental features'
complete -c rattler-build -n "__fish_seen_subcommand_from test" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from test" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from test" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -s p -l package-file -d 'The package file to rebuild' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -l output-dir -d 'Output directory for build artifacts. Defaults to `./output`' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -l auth-file -d 'Path to an auth-file to read authentication information from' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -l no-test -d 'Do not run tests after building'
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -l use-zstd -d 'Enable support for repodata.json.zst'
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -l use-bz2 -d 'Enable support for repodata.json.bz2'
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -l experimental -d 'Enable experimental features'
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from rebuild" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -l output-dir -d 'Output directory for build artifacts. Defaults to `./output`' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -l auth-file -d 'Path to an auth-file to read authentication information from' -r -F
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -l use-zstd -d 'Enable support for repodata.json.zst'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -l use-bz2 -d 'Enable support for repodata.json.bz2'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -l experimental -d 'Enable experimental features'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "quetz" -d 'Options for uploading to a Quetz server. Authentication is used from the keychain / auth-file'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "artifactory" -d 'Options for uploading to a Artifactory channel. Authentication is used from the keychain / auth-file'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "prefix" -d 'Options for uploading to a prefix.dev server. Authentication is used from the keychain / auth-file'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "anaconda" -d 'Options for uploading to a Anaconda.org server'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "conda-forge" -d 'Options for uploading to conda-forge'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from quetz" -s u -l url -d 'The URL to your Quetz server' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from quetz" -s c -l channel -d 'The URL to your channel' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from quetz" -s a -l api-key -d 'The Quetz API key, if none is provided, the token is read from the keychain / auth-file' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from quetz" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from quetz" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from quetz" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from quetz" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from quetz" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from artifactory" -s u -l url -d 'The URL to your Artifactory server' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from artifactory" -s c -l channel -d 'The URL to your channel' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from artifactory" -s r -l username -d 'Your Artifactory username' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from artifactory" -s p -l password -d 'Your Artifactory password' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from artifactory" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from artifactory" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from artifactory" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from artifactory" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from artifactory" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from prefix" -s u -l url -d 'The URL to the prefix.dev server (only necessary for self-hosted instances)' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from prefix" -s c -l channel -d 'The channel to upload the package to' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from prefix" -s a -l api-key -d 'The prefix.dev API key, if none is provided, the token is read from the keychain / auth-file' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from prefix" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from prefix" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from prefix" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from prefix" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from prefix" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -s o -l owner -d 'The owner of the distribution (e.g. conda-forge or your username)' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -s c -l channel -d 'The channel / label to upload the package to (e.g. main / rc)' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -s a -l api-key -d 'The Anaconda API key, if none is provided, the token is read from the keychain / auth-file' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -s u -l url -d 'The URL to the Anaconda server' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -s f -l force -d 'Replace files on conflict'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from anaconda" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l staging-token -d 'The Anaconda API key' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l feedstock -d 'The feedstock name' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l feedstock-token -d 'The feedstock token' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l staging-channel -d 'The staging channel name' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l anaconda-url -d 'The Anaconda Server URL' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l validation-endpoint -d 'The validation endpoint url' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l provider -d 'The CI provider' -r
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l post-comment-on-error -d 'Post comment on promotion failure'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -l dry-run -d 'Dry run, don\'t actually upload anything'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from conda-forge" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "quetz" -d 'Options for uploading to a Quetz server. Authentication is used from the keychain / auth-file'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "artifactory" -d 'Options for uploading to a Artifactory channel. Authentication is used from the keychain / auth-file'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "prefix" -d 'Options for uploading to a prefix.dev server. Authentication is used from the keychain / auth-file'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "anaconda" -d 'Options for uploading to a Anaconda.org server'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "conda-forge" -d 'Options for uploading to conda-forge'
complete -c rattler-build -n "__fish_seen_subcommand_from upload; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rattler-build -n "__fish_seen_subcommand_from completion" -s s -l shell -r -f -a "{bash	'',elvish	'',fish	'',powershell	'',zsh	''}"
complete -c rattler-build -n "__fish_seen_subcommand_from completion" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from completion" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from completion" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from completion" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from completion" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from generate-recipe" -l log-style -d 'Logging style' -r -f -a "{fancy	'Use fancy logging output',json	'Use JSON logging output',plain	'Use plain logging output'}"
complete -c rattler-build -n "__fish_seen_subcommand_from generate-recipe" -l color -d 'Enable or disable colored output from rattler-build. Also honors the `CLICOLOR` and `CLICOLOR_FORCE` environment variable' -r -f -a "{always	'Always use colors',never	'Never use colors',auto	'Use colors when the output is a terminal'}"
complete -c rattler-build -n "__fish_seen_subcommand_from generate-recipe" -s v -l verbose -d 'Increase logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from generate-recipe" -s q -l quiet -d 'Decrease logging verbosity'
complete -c rattler-build -n "__fish_seen_subcommand_from generate-recipe" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from build; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from completion; and not __fish_seen_subcommand_from generate-recipe; and not __fish_seen_subcommand_from help" -f -a "build" -d 'Build a package'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from build; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from completion; and not __fish_seen_subcommand_from generate-recipe; and not __fish_seen_subcommand_from help" -f -a "test" -d 'Test a package'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from build; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from completion; and not __fish_seen_subcommand_from generate-recipe; and not __fish_seen_subcommand_from help" -f -a "rebuild" -d 'Rebuild a package'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from build; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from completion; and not __fish_seen_subcommand_from generate-recipe; and not __fish_seen_subcommand_from help" -f -a "upload" -d 'Upload a package'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from build; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from completion; and not __fish_seen_subcommand_from generate-recipe; and not __fish_seen_subcommand_from help" -f -a "completion" -d 'Generate shell completion script'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from build; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from completion; and not __fish_seen_subcommand_from generate-recipe; and not __fish_seen_subcommand_from help" -f -a "generate-recipe" -d 'Generate a recipe from PyPI or CRAN'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from build; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from completion; and not __fish_seen_subcommand_from generate-recipe; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge" -f -a "quetz" -d 'Options for uploading to a Quetz server. Authentication is used from the keychain / auth-file'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge" -f -a "artifactory" -d 'Options for uploading to a Artifactory channel. Authentication is used from the keychain / auth-file'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge" -f -a "prefix" -d 'Options for uploading to a prefix.dev server. Authentication is used from the keychain / auth-file'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge" -f -a "anaconda" -d 'Options for uploading to a Anaconda.org server'
complete -c rattler-build -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from upload; and not __fish_seen_subcommand_from quetz; and not __fish_seen_subcommand_from artifactory; and not __fish_seen_subcommand_from prefix; and not __fish_seen_subcommand_from anaconda; and not __fish_seen_subcommand_from conda-forge" -f -a "conda-forge" -d 'Options for uploading to conda-forge'
